@@ -2,8 +2,9 @@
 class Config():
     appId = None
     apiKey = None
-    domain = "https://api.kalasearch.cn"
+    domain = None
 
-    def __init__(self, appId, apiKey):
+    def __init__(self, appId, apiKey, domain):
         self.appId = appId
-        self.apiKey = apiKey
\ No newline at end of file
+        self.apiKey = apiKey
+        self.domain = domain
\ No newline at end of file
