@@ -8,8 +8,8 @@ class HttpClient():
     def __init__(self, config):
         self.config = config
         self.headers = {
-            "apiKey": self.config.apiKey,
-            "appId": self.config.appId,
+            "X-Kalasearch-Id": self.config.appId,
+            "X-Kalasearch-Key": self.config.apiKey,
             "Content-Type": "application/json"
         }
 
@@ -26,3 +26,9 @@ class HttpClient():
 
     def post(self, path, body=None):
         return self.send_request(requests.post, path, body)
+
+    def put(self, path, body=None):
+        return self.send_request(requests.put, path, body)
+
+    def delete(self, path):
+        return self.send_request(requests.delete, path)
